@@ -13,6 +13,10 @@ class UnhandledPthFileError(GriffeError):
     """Exception for unhandled .path files, when searching modules."""
 
 
+class UnimportableModuleError(GriffeError):
+    """Exception for modules that cannot be imported."""
+
+
 class AliasResolutionError(GriffeError):
     """Exception for alias that cannot be resolved."""
 
@@ -32,3 +36,11 @@ class LastNodeError(GriffeError):
 
 class RootNodeError(GriffeError):
     """Exception raised when trying to use siblings properties on a root node."""
+
+
+class BuiltinModuleError(GriffeError):
+    """Exception raised when trying to access the filepath of a builtin module."""
+
+
+class ExtensionError(GriffeError):
+    """Base class for errors raised by extensions."""
